Crate testnumbat_wasm

Crate testnumbat_wasm 

Re-exports

pub use storage::storage_clear;
pub use storage::storage_get;
pub use storage::storage_get_len;
pub use storage::storage_set;
pub use testnumbat_codec;
pub use hex_call_data::*;
pub use io::*;

Modules

abi
api
contract_base
dcdt
err_msg
hex_call_data
io
log_util
non_zero_util
storage
types

Macros

derive_imports
Imports required for deriving serialization and TypeAbi.
imports
Getting all imports needed for a smart contract.
non_zero_usize
Converts usize to NonZeroUsize or returns SCError.
only_owner
Very compact way of not allowing anyone but the owner to call a function.
require
Allows us to write Solidity style require!(<condition>, <error_msg>) and avoid if statements.
sc_error
Compact way of returning a static error message.
sc_tryDeprecated
Equivalent to the ? operator for SCResult.

Structs

Box
A pointer type that uniquely owns a heap allocation of type T.
String
A UTF-8–encoded, growable string.
Vec
A contiguous growable array type, written as Vec<T>, short for ‘vector’.